# WIFI Bridge Documentation

## Simple Bridge

This directory contains files that can be used to setup the ESP8266 
chip with a simple bridge. This will configure the ESP8266 to be a WIFI access
point that can be accessed via the SSID uCart_AP. The ESP8266 chip will check
for data and if there is anything waiting the ESP will grab the data and send 
it back to the connected client as well as print it over serial.

**Note: ESP8266 Platform is required, see [Arduino Project Hub](https://create.arduino.cc/projecthub/ROBINTHOMAS/programming-esp8266-esp-01-with-arduino-011389) for in depth steps on how to add this.**

### SETUP 

In order to program the ESP8266 setup will be needed. First, obtain a ESP8266
chip and an Arduino UNO and wire as shown in the image below. The connections
that are needed are as follows:

  * Connect ground (GND) of the ESP-015 to the ground of the Arduino.
  * Connect GPIO 0 (I00) of the ESP-015 to the ground of the Arduino (only duri
    ng programming, otherwise do not connect this pin).
  * Connect enable (EN) of the ESP-015 to 3.3 V.
  * Connect vcc (3V3) of the ESP-015 to 3.3 V.
  * Connect RX of the ESP-015 to digital pin 0 (labeled RX<-0) of the Arduino.
  * Connect TX of the ESP-015 to digital pin 1 (labeled TX->0) of the Arduino.

**NOTE: In the image below GPIO 2 is connected to a LED, that is NOT needed
for our program, but can be used to provide visual feedback.**

**NOTE: In the image below 5V of the Arduino UNO is connected to a voltage divider. 
This is the better way to power the ESP8266 as the 3.3 V from the
Arduino UNO is poor. That being said, it does work to connect directly to 
3.3 V.**

Image taken from [Arduino Project Hub](https://create.arduino.cc/projecthub/ROBINTHOMAS/programming-esp8266-esp-01-with-arduino-011389)

![alt text](../images/ESP8266_setup.png "ESP8266 Setup")

### Programming

Once all connections are made first make sure that the GPIO 0 pin is connected
to ground for programming. Open the simple_bridge.ino file in the Arduino IDE
and verify/compile (use Verify button or Sketch->Verify/Compile). Then before
programming make sure that the Arduino UNO is connected to the computer and 
select the "Generic ESP8266 Module" as the board and the proper port for 
programming. Next upload the files (use Upload Button or Sketch->Upload).

After the Upload has completed (look for 'closing bootloader' and then 'flush 
complete'), and disconnect the Arduino UNO. Disconnect the GPIO 0 pin from the 
ESP8266 chip and reconnect the Arduino UNO to power the chip.

### Connecting to Access Point

After uploading the code one should be able to connected to the access point 
by finding the uCart_AP ssid in the wifi select window.

### Running TCP Corrup Test

Once connected to the access point the TCP Corrup Test can be run using python3.
The command is as follows: `python3 tcp_corrup_test.py`. This test will make
sure that communication is working between the ESP8266 and the connected client.
Upon successful completion of this test 'Successfully received 20000' will be printed.
